Sign inSign up

essentialkaos/bibop

By essentialkaos

•Updated about 22 hours ago

Utility for testing command-line tools

Image
Developer tools
0

10K+

essentialkaos/bibop repository overview

GitHub Actions CI Status GoReportCard codebeat badge GitHub Actions CodeQL Status

Usage demo⁠ • Installation⁠ • Usage⁠ • Build Status⁠ • License⁠


bibop is a utility for testing command-line tools and daemons. Initially, this utility was created for testing packages from ESSENTIAL KAOS Public Yum Repository⁠.

Information about bibop recipe syntax you can find in our cookbook⁠.

⁠Usage demo

demo

⁠Installation
⁠From source

To build the bibop from scratch, make sure you have a working Go 1.17+ workspace (instructions⁠), then:

go install github.com/essentialkaos/bibop
⁠Prebuilt binaries

You can download prebuilt binaries for Linux from EK Apps Repository⁠.

To install the latest prebuilt version of bibop, do:

bash <(curl -fsSL https://apps.kaos.st/get) bibop
⁠Docker support

You can use Docker containers⁠ for testing your packages. Install latest version of Docker, then:

curl -fL# -o bibop-docker https://kaos.sh/bibop/bibop-docker
chmod +x bibop-docker
sudo mv bibop-docker /usr/bin/
bibop-docker --image essentialkaos/bibop:centos7 your.recipe your-package.rpm

Official Docker images with bibop:

  • essentialkaos/bibop:centos7
⁠Recipe syntax highlighting
⁠Command-line completion

You can generate completion for bash, zsh or fish shell.

Bash:

sudo bibop --completion=bash 1> /etc/bash_completion.d/bibop

ZSH:

sudo bibop --completion=zsh 1> /usr/share/zsh/site-functions/bibop

Fish:

sudo bibop --completion=fish 1> /usr/share/fish/vendor_completions.d/bibop.fish
⁠Man documentation

You can generate man page for bibop using next command:

bibop --generate-man | sudo gzip > /usr/share/man/man1/bibop.1.gz
⁠Usage
Usage: bibop {options} recipe

Options

  --dry-run, -D             Parse and validate recipe
  --list-packages, -L       List required packages
  --format, -f format       Output format (tap|json|xml)
  --dir, -d dir             Path to working directory
  --path, -p path           Path to directory with binaries
  --error-dir, -e dir       Path to directory for errors data
  --tag, -t tag             Command tag
  --quiet, -q               Quiet mode
  --ignore-packages, -ip    Do not check system for installed packages
  --no-cleanup, -nl         Disable deleting files created during tests
  --no-color, -nc           Disable colors in output
  --help, -h                Show this help message
  --version, -v             Show version

Examples

  bibop app.recipe
  Run tests from app.recipe

  bibop app.recipe --quiet --error-dir bibop-errors
  Run tests from app.recipe in quiet mode and save errors data to bibop-errors directory

  bibop app.recipe --tag init,service
  Run tests from app.recipe and execute commands with tags init and service

  bibop app.recipe --format json 1> ~/results/app.json
  Run tests from app.recipe and save result in JSON format

⁠Build Status
BranchStatus
masterCI
developCI
⁠License

Apache License, Version 2.0⁠

Tag summary

Content type

Image

Digest

sha256:b5d47e27c…

Size

125.5 MB

Last updated

6 days ago

docker pull essentialkaos/bibop